Returns the path to the renmods cache directory. By default, creates the
directory if it doesn't exist (with user confirmation in interactive mode).
The cache location can be customized via the renmods.cache_dir option.
Returns the path to the renmods cache directory. By default, creates the
directory if it doesn't exist (with user confirmation in interactive mode).
The cache location can be customized via the renmods.cache_dir option.