Returns information about cached ENMODS data including when each data type was last downloaded, the date range it covers, and the file path.
Returns information about cached ENMODS data including when each data type was last downloaded, the date range it covers, and the file path.